@@ -1,6 +1,7 @@
 # flake8: noqa
 
 # import apis into api package
+from lusid_workflow.api.action_logs_api import ActionLogsApi
 from lusid_workflow.api.application_metadata_api import ApplicationMetadataApi
 from lusid_workflow.api.event_handlers_api import EventHandlersApi
 from lusid_workflow.api.task_definitions_api import TaskDefinitionsApi
@@ -9,6 +10,7 @@ from lusid_workflow.api.workers_api import WorkersApi
 
 
 __all__ = [
+    "ActionLogsApi",
     "ApplicationMetadataApi",
     "EventHandlersApi",
     "TaskDefinitionsApi",
